@@ -1,9 +1,9 @@
 /*  zomghelper, an information extractor for Ogg Vorbis files
-    Copyright (C) 2005, 2007  Clint Adams
+    Copyright (C) 2005-2013  Clint Adams
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2, or (at your option)
+    the Free Software Foundation; either version 3, or (at your option)
     any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -12,8 +12,7 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA */
+    along with this program.  If not, see <http://www.gnu.org/licenses/>. */
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -39,11 +38,19 @@ int main(int argc, char **argv) {
 	if (f==NULL)
 		exit(2);
 
-	ov_open(f, &vf, NULL, 0);
+	if (ov_test(f, &vf, NULL, 0))
+		exit(3);
+
+	if (ov_test_open(&vf))
+		exit(4);
 
 	k = ov_time_total(&vf,-1);
+	if (k == OV_EINVAL)
+		exit(5);
 
 	com = ov_comment(&vf,-1);
+	if (com == NULL)
+		exit(6);
 
 	printf("ZOMGSECS: %d\n", (int)ceil(k));
 
